==> cargo-sonar-0.1.3.crate: cargo-sonar-0.1.3/CHANGELOG.md <==
# Changelog
All notable changes to this project will be documented in this file. See [conventional commits](https://www.conventionalcommits.org/) for commit guidelines.

- - -
## 0.1.3 - 2021-10-26


### Continuous Integration

[1e04f7](https://gitlab.com/woshilapin/cargo-sonar/-/commit/1e04f7d943f59d6d70a89938e78188764c9eea3a) - update 'Cargo.lock' when tagging a new version - Jean SIMARD


### Bug Fixes

[77793c](https://gitlab.com/woshilapin/cargo-sonar/-/commit/77793c7392fdd9d674f51e8659b01849eb574078) - remove full-path of trait in the edition2021's prelude - Jean SIMARD


- - -
## 0.1.2 - 2021-10-26


### Tests

[c37008](https://gitlab.com/woshilapin/cargo-sonar/-/commit/c37008edfb3fb9803dc75d0273976f18b024b43a) - add test for cargo parsing - Jean SIMARD


### Bug Fixes

[61b46b](https://gitlab.com/woshilapin/cargo-sonar/-/commit/61b46b63c36bc1a5a385219ef1d79b6b2e54832f) - TryFrom/TryInto is in the prelude in edition2021 - Jean SIMARD


### Continuous Integration

[b316e7](https://gitlab.com/woshilapin/cargo-sonar/-/commit/b316e7e538aad2dddb393843e954b7e07fc8ca5b) - add 'cargo test' - Jean SIMARD

[8f6924](https://gitlab.com/woshilapin/cargo-sonar/-/commit/8f692444d1f9f8d1d1238b7cd1200de9a05e4639) - remove useless braces for variables - Jean SIMARD

[5137b5](https://gitlab.com/woshilapin/cargo-sonar/-/commit/5137b5e9a8a1759a618825ff597d1389283603d3) - use full-path container image - Jean SIMARD


- - -
## 0.1.1 - 2021-10-25


### Continuous Integration

[1e71e9](https://gitlab.com/woshilapin/cargo-sonar/-/commit/1e71e9ba3b4465bc53f5dbe824df6b3bb106ea6c) - automatically bump version of Cargo.toml - Jean SIMARD

[effd19](https://gitlab.com/woshilapin/cargo-sonar/-/commit/effd19bf84b8be1b0427a880c5a987a0089e2f38) - setting up git user is only useful for tagging - Jean SIMARD

[4c9fd1](https://gitlab.com/woshilapin/cargo-sonar/-/commit/4c9fd19c1be0ec60fee208788d572a39a033bdb7) - automatic release of OCI image to Dockerhub - Jean SIMARD


### Miscellaneous Chores

[abef2d](https://gitlab.com/woshilapin/cargo-sonar/-/commit/abef2d5e67f037990798af76bdf89fb4b7340867) - revert 0.1.1 - Jean SIMARD

[258609](https://gitlab.com/woshilapin/cargo-sonar/-/commit/25860929833ef4315850443aa1c492898f3ac11e) - 0.1.1 - gitlab-ci


### Bug Fixes

[9df357](https://gitlab.com/woshilapin/cargo-sonar/-/commit/9df3575cd71aa4f78b02c0edd6bb995627c22c42) - need to update to 'cargo:0.57' to support edition 2021 - Jean SIMARD


### Documentation

[845c08](https://gitlab.com/woshilapin/cargo-sonar/-/commit/845c08ea330ac7183a056b7df3538b4478a0d5ad) - add TODO about documentation - Jean SIMARD

[7fc945](https://gitlab.com/woshilapin/cargo-sonar/-/commit/7fc945e5baac6b5cd03beec7a088b6e2c2bf5d33) - open-source the project - Jean SIMARD


### Build system

[b1163c](https://gitlab.com/woshilapin/cargo-sonar/-/commit/b1163c6bddfac794070790358e5af67227e964c6) - update to Rust 1.56.0 - Jean SIMARD


- - -
## 0.1.0 - 2021-10-25


### Documentation

[ffa03c](https://gitlab.com/woshilapin/cargo-sonar/-/commit/ffa03cf9f907b90d43f0f95f24f9c9334e9e9327) - add a license file - Jean SIMARD

[4028b0](https://gitlab.com/woshilapin/cargo-sonar/-/commit/4028b00ea50925d45c6e7aae8345f4a711313254) - add a 'README.md' - Jean SIMARD


### Continuous Integration

[1b841b](https://gitlab.com/woshilapin/cargo-sonar/-/commit/1b841becd711ba2209f1fd18ef5579d24d1eb1c6) - automatic release - Jean SIMARD

[ef25d4](https://gitlab.com/woshilapin/cargo-sonar/-/commit/ef25d47c61e76144c74356c7ae24fe5874795c25) - add typos checking - Jean SIMARD

[27f42b](https://gitlab.com/woshilapin/cargo-sonar/-/commit/27f42b2f8c4c0c6fe8f5798a655eacbf5980c301) - improve conventional commit check - Jean SIMARD

[d58a17](https://gitlab.com/woshilapin/cargo-sonar/-/commit/d58a177135a31f906a3ade7249686101ca4c18a6) - add sonar-scanner configuration - Jean SIMARD

[6ae7e1](https://gitlab.com/woshilapin/cargo-sonar/-/commit/6ae7e1361896fb60214dedd07f2c64edda54d811) - add cocogitto check for conventional commits - Jean SIMARD

[004a35](https://gitlab.com/woshilapin/cargo-sonar/-/commit/004a35ab4b50cbf992db0b24f835e1f835e74907) - explode in multiple files - Jean SIMARD

[b4fac6](https://gitlab.com/woshilapin/cargo-sonar/-/commit/b4fac680ac29066bf0a8a907b5c5fb905c51c0df) - add clippy check - Jean SIMARD


### Features

[ebb1b4](https://gitlab.com/woshilapin/cargo-sonar/-/commit/ebb1b47c8fa67f23e8c533d50383b4f7d68ed8da) - convert audit reports into sonar reports - Jean SIMARD

[3f86d4](https://gitlab.com/woshilapin/cargo-sonar/-/commit/3f86d4f0fd66e90b2a5c7e75d00b7f293b51e724) - add cargo parsing for text ranges - Jean SIMARD

[a8293e](https://gitlab.com/woshilapin/cargo-sonar/-/commit/a8293eeb56849bac32a112f5395f25f8fdcd0b98) - replace 'anyhow' with 'eyre' and 'color_eyre' - Jean SIMARD

[10aeb1](https://gitlab.com/woshilapin/cargo-sonar/-/commit/10aeb1a871a7cf98d98fe9164a5bc2bf1d340b6b) - add error handling with anyhow - Jean SIMARD

[5ada39](https://gitlab.com/woshilapin/cargo-sonar/-/commit/5ada39ec7a74ca663fb243824e2ab58fc6b59311) - add 'tracing' for logging - Jean SIMARD

[721099](https://gitlab.com/woshilapin/cargo-sonar/-/commit/7210997e23e43e2b5e88d5e7736cb93d1c3d7085) - run 'cargo audit' without parsing yet - Jean SIMARD

[7d0bb9](https://gitlab.com/woshilapin/cargo-sonar/-/commit/7d0bb95a1fe107c6fbdfe137d67a6212eff87296) - stream cargo clippy result to produce output - Jean SIMARD


### Miscellaneous Chores

[3d71bc](https://gitlab.com/woshilapin/cargo-sonar/-/commit/3d71bc5f5a360dae836190b7b1630312ed62bb1a) - improve metadata in Cargo.toml - Jean SIMARD


### Refactoring

[5add33](https://gitlab.com/woshilapin/cargo-sonar/-/commit/5add330e9c715fc4164a22fbc9143241b3643656) - move all parsing into sub-modules - Jean SIMARD


- - -

This changelog was generated by [cocogitto](https://github.com/oknozor/cocogitto).

==> cargo-sonar-0.2.0.crate: cargo-sonar-0.2.0/CHANGELOG.md <==
# Changelog
All notable changes to this project will be documented in this file. See [conventional commits](https://www.conventionalcommits.org/) for commit guidelines.

- - -
## 0.2.0 - 2021-10-27


### Miscellaneous Chores

[8fe82b](https://gitlab.com/woshilapin/cargo-sonar/-/commit/8fe82b90549eae847114f3838cf2a0fedeb132fa) - add some FIXME/TODO with ideas for improvements - Jean SIMARD


### Features

[44412c](https://gitlab.com/woshilapin/cargo-sonar/-/commit/44412c8ee403fa02e7c1d597528e12cc96075fb1) - clippy is configured in 'pedantic' mode - Jean SIMARD

[61ef39](https://gitlab.com/woshilapin/cargo-sonar/-/commit/61ef39b52466a172c2c66567d482f3081419d9d2) - docker image now includes 'clippy' and 'audit' - Jean SIMARD


- - -
## 0.1.3 - 2021-10-26


### Continuous Integration

[1e04f7](https://gitlab.com/woshilapin/cargo-sonar/-/commit/1e04f7d943f59d6d70a89938e78188764c9eea3a) - update 'Cargo.lock' when tagging a new version - Jean SIMARD


### Bug Fixes

[77793c](https://gitlab.com/woshilapin/cargo-sonar/-/commit/77793c7392fdd9d674f51e8659b01849eb574078) - remove full-path of trait in the edition2021's prelude - Jean SIMARD


- - -
## 0.1.2 - 2021-10-26


### Tests

[c37008](https://gitlab.com/woshilapin/cargo-sonar/-/commit/c37008edfb3fb9803dc75d0273976f18b024b43a) - add test for cargo parsing - Jean SIMARD


### Bug Fixes

[61b46b](https://gitlab.com/woshilapin/cargo-sonar/-/commit/61b46b63c36bc1a5a385219ef1d79b6b2e54832f) - TryFrom/TryInto is in the prelude in edition2021 - Jean SIMARD


### Continuous Integration

[b316e7](https://gitlab.com/woshilapin/cargo-sonar/-/commit/b316e7e538aad2dddb393843e954b7e07fc8ca5b) - add 'cargo test' - Jean SIMARD

[8f6924](https://gitlab.com/woshilapin/cargo-sonar/-/commit/8f692444d1f9f8d1d1238b7cd1200de9a05e4639) - remove useless braces for variables - Jean SIMARD

[5137b5](https://gitlab.com/woshilapin/cargo-sonar/-/commit/5137b5e9a8a1759a618825ff597d1389283603d3) - use full-path container image - Jean SIMARD


- - -
## 0.1.1 - 2021-10-25


### Continuous Integration

[1e71e9](https://gitlab.com/woshilapin/cargo-sonar/-/commit/1e71e9ba3b4465bc53f5dbe824df6b3bb106ea6c) - automatically bump version of Cargo.toml - Jean SIMARD

[effd19](https://gitlab.com/woshilapin/cargo-sonar/-/commit/effd19bf84b8be1b0427a880c5a987a0089e2f38) - setting up git user is only useful for tagging - Jean SIMARD

[4c9fd1](https://gitlab.com/woshilapin/cargo-sonar/-/commit/4c9fd19c1be0ec60fee208788d572a39a033bdb7) - automatic release of OCI image to Dockerhub - Jean SIMARD


### Miscellaneous Chores

[abef2d](https://gitlab.com/woshilapin/cargo-sonar/-/commit/abef2d5e67f037990798af76bdf89fb4b7340867) - revert 0.1.1 - Jean SIMARD

[258609](https://gitlab.com/woshilapin/cargo-sonar/-/commit/25860929833ef4315850443aa1c492898f3ac11e) - 0.1.1 - gitlab-ci


### Bug Fixes

[9df357](https://gitlab.com/woshilapin/cargo-sonar/-/commit/9df3575cd71aa4f78b02c0edd6bb995627c22c42) - need to update to 'cargo:0.57' to support edition 2021 - Jean SIMARD


### Documentation

[845c08](https://gitlab.com/woshilapin/cargo-sonar/-/commit/845c08ea330ac7183a056b7df3538b4478a0d5ad) - add TODO about documentation - Jean SIMARD

[7fc945](https://gitlab.com/woshilapin/cargo-sonar/-/commit/7fc945e5baac6b5cd03beec7a088b6e2c2bf5d33) - open-source the project - Jean SIMARD


### Build system

[b1163c](https://gitlab.com/woshilapin/cargo-sonar/-/commit/b1163c6bddfac794070790358e5af67227e964c6) - update to Rust 1.56.0 - Jean SIMARD


- - -
## 0.1.0 - 2021-10-25


### Documentation

[ffa03c](https://gitlab.com/woshilapin/cargo-sonar/-/commit/ffa03cf9f907b90d43f0f95f24f9c9334e9e9327) - add a license file - Jean SIMARD

[4028b0](https://gitlab.com/woshilapin/cargo-sonar/-/commit/4028b00ea50925d45c6e7aae8345f4a711313254) - add a 'README.md' - Jean SIMARD


### Continuous Integration

[1b841b](https://gitlab.com/woshilapin/cargo-sonar/-/commit/1b841becd711ba2209f1fd18ef5579d24d1eb1c6) - automatic release - Jean SIMARD

[ef25d4](https://gitlab.com/woshilapin/cargo-sonar/-/commit/ef25d47c61e76144c74356c7ae24fe5874795c25) - add typos checking - Jean SIMARD

[27f42b](https://gitlab.com/woshilapin/cargo-sonar/-/commit/27f42b2f8c4c0c6fe8f5798a655eacbf5980c301) - improve conventional commit check - Jean SIMARD

[d58a17](https://gitlab.com/woshilapin/cargo-sonar/-/commit/d58a177135a31f906a3ade7249686101ca4c18a6) - add sonar-scanner configuration - Jean SIMARD

[6ae7e1](https://gitlab.com/woshilapin/cargo-sonar/-/commit/6ae7e1361896fb60214dedd07f2c64edda54d811) - add cocogitto check for conventional commits - Jean SIMARD

[004a35](https://gitlab.com/woshilapin/cargo-sonar/-/commit/004a35ab4b50cbf992db0b24f835e1f835e74907) - explode in multiple files - Jean SIMARD

[b4fac6](https://gitlab.com/woshilapin/cargo-sonar/-/commit/b4fac680ac29066bf0a8a907b5c5fb905c51c0df) - add clippy check - Jean SIMARD


### Features

[ebb1b4](https://gitlab.com/woshilapin/cargo-sonar/-/commit/ebb1b47c8fa67f23e8c533d50383b4f7d68ed8da) - convert audit reports into sonar reports - Jean SIMARD

[3f86d4](https://gitlab.com/woshilapin/cargo-sonar/-/commit/3f86d4f0fd66e90b2a5c7e75d00b7f293b51e724) - add cargo parsing for text ranges - Jean SIMARD

[a8293e](https://gitlab.com/woshilapin/cargo-sonar/-/commit/a8293eeb56849bac32a112f5395f25f8fdcd0b98) - replace 'anyhow' with 'eyre' and 'color_eyre' - Jean SIMARD

[10aeb1](https://gitlab.com/woshilapin/cargo-sonar/-/commit/10aeb1a871a7cf98d98fe9164a5bc2bf1d340b6b) - add error handling with anyhow - Jean SIMARD

[5ada39](https://gitlab.com/woshilapin/cargo-sonar/-/commit/5ada39ec7a74ca663fb243824e2ab58fc6b59311) - add 'tracing' for logging - Jean SIMARD

[721099](https://gitlab.com/woshilapin/cargo-sonar/-/commit/7210997e23e43e2b5e88d5e7736cb93d1c3d7085) - run 'cargo audit' without parsing yet - Jean SIMARD

[7d0bb9](https://gitlab.com/woshilapin/cargo-sonar/-/commit/7d0bb95a1fe107c6fbdfe137d67a6212eff87296) - stream cargo clippy result to produce output - Jean SIMARD


### Miscellaneous Chores

[3d71bc](https://gitlab.com/woshilapin/cargo-sonar/-/commit/3d71bc5f5a360dae836190b7b1630312ed62bb1a) - improve metadata in Cargo.toml - Jean SIMARD


### Refactoring

[5add33](https://gitlab.com/woshilapin/cargo-sonar/-/commit/5add330e9c715fc4164a22fbc9143241b3643656) - move all parsing into sub-modules - Jean SIMARD


- - -

This changelog was generated by [cocogitto](https://github.com/oknozor/cocogitto).
